Index: chrome/browser/infobars/infobar_container.h |
diff --git a/chrome/browser/infobars/infobar_container.h b/chrome/browser/infobars/infobar_container.h |
index c1b6633bbc38fe078736d76c3fc19aaf5c20bf77..4cfd3644b264e8ca3e93a1d78e5101d576c7f319 100644 |
--- a/chrome/browser/infobars/infobar_container.h |
+++ b/chrome/browser/infobars/infobar_container.h |
@@ -38,7 +38,7 @@ class SearchModel; |
// temporarily if the user changes into |SEARCH_SUGGESTIONS| mode (refer to |
// chrome::search::Mode in chrome/common/search_types.h for all search modes) |
// when on a : |
// - |DEFAULT| page: when instant preview is ready; |
// - |NTP| or |SEARCH_RESULTS| page: immediately; |
// TODO(kuan): this scenario requires more complex synchronization with |
// renderer SearchBoxAPI and will be implemented as the next step; |
@@ -51,7 +51,7 @@ class SearchModel; |
// to re-hide infobars without animation is canceled if a tab change occurs. |
class InfoBarContainer : public content::NotificationObserver, |
public chrome::search::SearchModelObserver, |
- public InstantModelObserver { |
+ public InstantModelObserver { |
public: |
class Delegate { |
public: |
@@ -111,7 +111,7 @@ class InfoBarContainer : public content::NotificationObserver, |
const Delegate* delegate() const { return delegate_; } |
// InstantModelObserver: |
- virtual void PreviewStateChanged(const InstantModel& model) OVERRIDE; |
+ virtual void OverlayStateChanged(const InstantModel& model) OVERRIDE; |
protected: |
// Subclasses must call this during destruction, so that we can remove |
@@ -38,7 +38,7 @@ class SearchModel; |
// chrome::search::Mode in chrome/common/search_types.h for all search modes) |
// when on a : |
-// - |DEFAULT| page: when instant preview is ready; |
+// - |DEFAULT| page: when Instant overlay is ready; |
// - |NTP| or |SEARCH_RESULTS| page: immediately; |
// TODO(kuan): this scenario requires more complex synchronization with |